\name{gslider}
\alias{gslider}
\alias{gspinbutton}
\title{ Constructors for widgets to select a value from a sequence.}
\description{
	The gslider widget and gspinbutton widget allow the user to
	select a value from a sequence using the mouse. In the slider
	case, a slider is dragged left or right (or up or down) to
	change the value. For a spin button a text box with arrows
	beside allow the user to scroll through the values by clicking
	the arrows.
}
\usage{
gslider(from = 0, to = 100, by = 1, value = from, horizontal = TRUE, handler = NULL, action = NULL, container = NULL, ..., toolkit = guiToolkit())

gspinbutton (from = 0, to = 10, by = 1, value = from, digits = 0, 
    handler = NULL, action = NULL, container = NULL, ..., toolkit = guiToolkit()) 
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{from}{Starting point in range}
  \item{to}{Ending point in range}
  \item{by}{Step size between values in the sequence}
  \item{value}{ The initial value }
  \item{digits}{The number of digits shown}
  \item{horizontal}{Specifies orientation of gslider widget}
  \item{handler}{Called on a change event.}
  \item{action}{Passed to handler }
  \item{container}{ Optional container to attach widget to}
  \item{\dots}{ignored}
    \item{toolkit}{Which GUI toolkit to use}

}
\details{
	The \code{svalue} method returns the selected value.

	The \code{svalue<-} method is used to set the selected value.

	The \code{addhandlerchanged} handler is called when the
	widgets' value is changed.
}
\value{}
\references{}
\author{}
\note{}
\seealso{}
\examples{
\dontrun{
  x = rnorm(100)
  plotHist = function(shade = .5) hist(x, col=gray(shade))

  group = ggroup(horizontal =FALSE, container=TRUE)
  glabel("Slide value to adjust shade", container=group)
  gslider(from=0,to=1,by=0.05,value=.5, container=group,
  handler=function(h,...)  plotHist(svalue(h$obj)))
}
}
\keyword{interface}% at least one, from doc/KEYWORDS
